# 🛠 Contributing to Fetchez

Thank you for considering contributing to Fetchez! We welcome contributions from the community to help make geospatial data acquisition easier for everyone.

[Our Contributor Guide](https://fetchez.readthedocs.io/en/latest/contribute/index.html) will help you get started, whether you're fixing a bug, adding a new data module, or improving documentation.
